function [VarLabels]=add_variable(VarLabels,Catergory,VarName,SWFTData_Path)
%
% Description: Adding a new variable to the list of variables requested by
%   SWFT GUI. A new variable is defined by its name and its category. Since
%   the SWFT database contains multiple datasets. A dataset may contain
%   several categories of data. The mapping between a category of data and
%   the dataset containg the category is done by finding at least one
%   variable in the dataset that belongs to the specified category. Even
%   though the variable name can potentially contain 3 pieces of information:
%   its native name, local statistic label and time stamp, this routine does
%   not parse the variable name.
% Usage: [VarLabels]=add_variable(VarLabels,Catergory,VarName,SWFTData_Path)
%   Inputs:
%        VarLabels      : List of variables is a structure array with the
%                         following fields:
%                            DataSetName  : Name of data set the variable
%                                           belongs.
%                            VariableName : Composite name of a variable.
%        Catergory      : Category label, a character string.
%        VarName        : Variable name
%        SWFTData_Path  : Path to SWFT match-up database.
%
%
filelist=dir([SWFTData_Path,filesep,'GIMvSpace_Matchup*.mat']);
if isempty(filelist)
    disp(['add_variable: Folder ',SWFTData_Path,' does not contain SWFT data files.']);
    DataCategory=[];
    return;
end
SWFT_Dataset=load([filelist(1).folder,filesep,filelist(1).name]);
%
% Check for format of match-up data.
%
if ~isfield(SWFT_Dataset,'SWFT_Dataset')
    disp('add_variable: Format of SWFT database has changed for the new SWFT. Please find new match-up data.');
    return;
else
    SWFT_Dataset=SWFT_Dataset.SWFT_Dataset;
end
%
% Update variable list with new dataset names.
%
nVar=length(VarLabels);
for iVar=1:nVar
    switch VarLabels(iVar).DataSetName
        case 'DataSet'
            VarLabels(iVar).DataSetName='Physical';
        case 'SingleAttrib_Anaomaly'
            VarLabels(iVar).DataSetName='AnomalyFlags';
    end
end
%
% Get the name of all datasets in the mathc-up data.
%
DataSet_List=fieldnames(SWFT_Dataset);
nDataSet=length(DataSet_List);
for iDataSet=1:nDataSet
    %
    % Skip the Time Grid.
    %
    if strcmp(DataSet_List{iDataSet},'TimeGrid')
        continue;
    end
    %
    % Search for each dataset for variable of specified category.
    %
    v=getfield(SWFT_Dataset,DataSet_List{iDataSet});
    Fieldlist=fieldnames(v);
    for iField=1:length(Fieldlist)
        u=getfield(v,Fieldlist{iField});
        if strcmp(u.Category,Catergory)
            % 
            % If a variable in a dataset belongs to the specified category,
            % the new variable must be contain in this dataset.
            %
            ind=find((strcmpi({VarLabels(:).DataSetName},DataSet_List{iDataSet})==1) &...
                (strcmpi({VarLabels(:).VariableName},VarName)==1));
            if ~isempty(ind)
                disp('add_variable: Variable already exists in the variable list.');
                return;
            else
                nVar=length(VarLabels);
                VarLabels(nVar+1).DataSetName=DataSet_List{iDataSet};
                VarLabels(nVar+1).VariableName=VarName;
                return;
            end
        end
    end            
end
disp(['add_variable: Catergory ',Catergory,' is not found in data files.']);
return;
end