function [DataCollection]=extractMatchupData(VarLabels,...
    FirstDateNum,LastDateNum,MatchupDir)
%
% Description: extract a subset of data from the matchup database.
% Usage: [DataCollection]=extractMatchupData(DataSetName,DataFieldList,FirstDateNum,LastDataNum,MatchupDir)
%    Inputs:
%       VarLabels      : Structure array of names of variables.
%       FirstDateNum   : Date number of the first data point. Date number is assumed
%                        to be a data field in DataSet in the match up
%                        files.
%       LastDateNum    : Date number of the last data point.
%       MatchupDir     : Directory of the match up data file.
%
[VarInfo]=getVarInfo(VarLabels,MatchupDir);
DataCollection=struct('FirstDateNum',FirstDateNum,'LastDateNum',LastDateNum);
%
% Identify the extend of data in years required.
%
[year0,~,~,~,~,~]=datevec(FirstDateNum);
[year1,~,~,~,~,~]=datevec(LastDateNum);
DataCollection.SourceFileName=cell(1,year1-year0+1);
DataCollection.DataIndex=cell(1,year1-year0+1);
%
% Identify the datasets involved.
%
DataSetName=unique({VarInfo(:).DataSet});
nDataSet=length(DataSetName);
%
% Loop over all years where data is requested.
%
for iYear=1:year1-year0+1
    DataFileName=['GIMvSpace_Matchup_',num2str(year0+iYear-1),'.mat'];
    fileinfo=dir([MatchupDir,filesep,DataFileName]);
    if isempty(fileinfo)
        disp(['DataCollection: File ',DataFileName,' cannot be found.']);
        DataCollection=[];
        return;
    end
    %
    % Initialize the data traceability information for each data point:
    % which file it is extracted and which index in the data array it
    % belongs.
    %
    DataCollection.SourceFileName{iYear}=DataFileName;
    load([MatchupDir,filesep,DataFileName]);
    DataCollection.DataIndex{iYear}=find((SWFT_Dataset.TimeGrid.DateNum_Start.Value>=FirstDateNum)&...
        (SWFT_Dataset.TimeGrid.DateNum_End.Value<=LastDateNum));
    %
    % Generally, there should not be empty time index for a given year
    % unless there are missing data in the database.
    %
    if isempty(DataCollection.DataIndex{iYear})
        continue;
    end
    %
    % Initialize the data fields.
    %
    if iYear==1
        DataCollection.DateNum_Start=[];
        DataCollection.DateNum_End=[];
        for iDataSet=1:nDataSet
            ind=find(strcmp({VarInfo(:).DataSet},DataSetName{iDataSet})==1);
            VarNameList=unique({VarInfo(ind).VarName});
            v=struct(VarNameList{1},[]);
            for iVar=2:length(VarNameList)
                v=setfield(v,VarNameList{iVar},[]);
            end
            DataCollection=setfield(DataCollection,DataSetName{iDataSet},v);
        end
    end
    DataCollection.DateNum_Start=[DataCollection.DateNum_Start,...
        SWFT_Dataset.TimeGrid.DateNum_Start.Value(DataCollection.DataIndex{iYear})];
    DataCollection.DateNum_End=[DataCollection.DateNum_End,...
        SWFT_Dataset.TimeGrid.DateNum_End.Value(DataCollection.DataIndex{iYear})];
    for iDataSet=1:nDataSet
        DataSet=getfield(SWFT_Dataset,DataSetName{iDataSet});
        ind=find(strcmp({VarInfo(:).DataSet},DataSetName{iDataSet})==1);
        VarNameList=unique({VarInfo(ind).VarName});
        DataCollection_DataSet=getfield(DataCollection,DataSetName{iDataSet});
        for iVar=1:length(VarNameList)
            u=getfield(DataSet,VarNameList{iVar});
            v=getfield(DataCollection_DataSet,VarNameList{iVar});
            if isfield(u,'Value')
                v=[v,u.Value(DataCollection.DataIndex{iYear})];
            elseif isfield(u,'AnomalyFlag')
                v=[v,u.AnomalyFlag(DataCollection.DataIndex{iYear})];
            end
            DataCollection_DataSet=setfield(DataCollection_DataSet,VarNameList{iVar},v);
        end
        DataCollection=setfield(DataCollection,DataSetName{iDataSet},DataCollection_DataSet);
    end
end
return;
end